DecorrelatedModifiedBlackBody — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- DecorrelatedModifiedBlackBody

# DecorrelatedModifiedBlackBody

class `pysm.` `DecorrelatedModifiedBlackBody`(map_I=None, map_Q=None, map_U=None, freq_ref_I=None, freq_ref_P=None, map_mbb_index=None, map_mbb_temperature=None, nside=None, pixel_indices=None, mpi_comm=None, correlation_length=None)

  Bases: `pysm.ModifiedBlackBody`

  See parent class for other documentation.

  Parameters
    correlation_length: float

      This number set the scale in logarithmic space for the distance in freuqency past which the MBB emission becomes decorrelated. For frequencies much much closer than this distance, the emission is well correlated.

  Methods Summary

  `get_emission`(self, freqs) | Function to calculate the emission of a decorrelated modified black body model.

  Methods Documentation

  `get_emission`(self, freqs)

    Function to calculate the emission of a decorrelated modified black body model.